@@ -1,6 +1,6 @@
 from .h5 import h5py_to_binary
-from .nwb import save_nwb, read_nwb
-from .save import combined, compute_dydx
+from .nwb import save_nwb, read_nwb, nwb_to_binary
+from .save import combined, compute_dydx, save_mat
 from .sbx import sbx_to_binary
 from .tiff import mesoscan_to_binary, ome_to_binary, tiff_to_binary, generate_tiff_filename, save_tiff
 from .binary import BinaryFile, BinaryFileCombined
