@@ -7,7 +7,7 @@ from getpass import getpass
 import pathlib
 
 import numpy as np
-from scipy.io import savemat
+#from scipy.io import savemat
 
 from . import extraction, io, registration, detection, classification
 from .version import version
@@ -37,6 +37,9 @@ def default_ops():
         'bruker_bidirectional': False, # bidirectional multiplane in bruker: 0, 1, 2, 2, 1, 0 (True) vs 0, 1, 2, 0, 1, 2 (False)
         'h5py': [],  # take h5py as input (deactivates data_path)
         'h5py_key': 'data',  #key in h5py where data array is stored
+        'nwb_file': '', # take nwb file as input (deactivates data_path)
+        'nwb_driver': '', # driver for nwb file (nothing if file is local)
+        'nwb_series': '', # TwoPhotonSeries name, defaults to first TwoPhotonSeries in nwb file
         'save_path0': [],  # stores results, defaults to first item in data_path
         'save_folder': [],
         'subfolders': [],
@@ -295,24 +298,11 @@ def run_plane(ops, ops_path=None, stat=None):
 
         # save as matlab file
         if ops.get('save_mat'):
-            ops_matlab = ops.copy()
-            if isinstance(ops_matlab.get('date_proc'), datetime):
-                ops_matlab['date_proc'] = datetime.strftime(ops_matlab['date_proc'], "%Y-%m-%d %H:%M:%S.%f"),
-            for k in ops_matlab.keys():
-                if isinstance(ops_matlab[k], pathlib.Path):
-                    ops_matlab[k] = os.fspath(ops_matlab[k].absolute())
-            ops_matlab['data_path'] = [os.fspath(p.absolute()) for p in ops_matlab['data_path']]
-            savemat(
-                file_name=os.path.join(ops['save_path'], 'Fall.mat'),
-                mdict={
-                    'stat': np.load(os.path.join(fpath, 'stat.npy'), allow_pickle=True),
-                    'ops': ops_matlab,
-                    'F': F,
-                    'Fneu': Fneu,
-                    'spks': spks,
-                    'iscell': np.load(os.path.join(fpath, 'iscell.npy'))
-                }
-            )
+            stat = np.load(os.path.join(ops['save_path'], 'stat.npy'), allow_pickle=True)
+            iscell = np.load(os.path.join(ops['save_path'], 'iscell.npy'))
+            redcell = np.load(os.path.join(ops['save_path'], 'redcell.npy')) if ops['nchannels']==2 else []
+            io.save_mat(ops, stat, F, Fneu, spks, iscell, redcell)
+            
     else:
         print("WARNING: skipping cell detection (ops['roidetect']=False)")
 
@@ -368,7 +358,12 @@ def run_s2p(ops={}, db={}, server={}):
         ops['aspect'] = ops['diameter'][0] / ops['diameter'][1]
     print(db)
     if 'save_path0' not in ops or len(ops['save_path0'])==0:
-        ops['save_path0'] = os.path.split(ops['h5py'])[0] if ops.get('h5py') else ops['data_path'][0]
+        if ops.get('h5py'):
+            ops['save_path0'] = os.path.split(ops['h5py'])[0]
+        elif ops.get('nwb_file'):
+            ops['save_path0'] = os.path.split(ops['nwb_file'])[0]
+        else:
+            ops['save_path0'] = ops['data_path'][0]
     
     # check if there are binaries already made
     if 'save_folder' not in ops or len(ops['save_folder'])==0:
@@ -391,6 +386,8 @@ def run_s2p(ops={}, db={}, server={}):
     else:
         if len(ops['h5py']):
             ops['input_format'] = 'h5'
+        elif len(ops['nwb_file']):
+            ops['input_format'] = 'nwb'
         elif ops.get('mesoscan'):
             ops['input_format'] = 'mesoscan'
         elif HAS_HAUS:
@@ -402,6 +399,7 @@ def run_s2p(ops={}, db={}, server={}):
         # copy file format to a binary file
         convert_funs = {
             'h5': io.h5py_to_binary,
+            'nwb': io.nwb_to_binary,
             'sbx': io.sbx_to_binary,
             'mesoscan': io.mesoscan_to_binary,
             'haus': lambda ops: haussio.load_haussio(ops['data_path'][0]).tosuite2p(ops.copy()),
